This is an automated email from the ASF dual-hosted git repository.

tison pushed a commit to branch dev
in repository 
https://gitbox.apache.org/repos/asf/incubator-streampark-website.git


The following commit(s) were added to refs/heads/dev by this push:
     new efe0a63e [Fix] Swizzles
efe0a63e is described below

commit efe0a63e0dc485d239ffcbccb20a1fbf4bfb3c65
Author: tison <[email protected]>
AuthorDate: Wed May 15 22:21:50 2024 +0800

    [Fix] Swizzles
    
    Signed-off-by: tison <[email protected]>
---
 blog/3-streampark-usercase-bondex-paimon.md        |  7 ++++-
 community/release/How-to-release.md                |  8 +++---
 .../3-streampark-usercase-bondex-paimon.md         |  7 ++++-
 .../current/release/How-to-release.md              |  8 +++---
 package.json                                       | 22 +++++++--------
 pnpm-lock.yaml                                     | 32 ++++++++--------------
 src/theme/DocCard/index.js                         |  5 ++--
 src/theme/DocSidebarItem/Category/index.js         |  6 ++--
 8 files changed, 48 insertions(+), 47 deletions(-)

diff --git a/blog/3-streampark-usercase-bondex-paimon.md 
b/blog/3-streampark-usercase-bondex-paimon.md
index f3be5ec9..140df95b 100644
--- a/blog/3-streampark-usercase-bondex-paimon.md
+++ b/blog/3-streampark-usercase-bondex-paimon.md
@@ -846,13 +846,18 @@ Upon investigation, it was discovered that the issue was 
caused by the configura
 **3. Aggregate function 'last_non_null_value' does not support retraction**
 
 Error:
+
+```
 Caused by: java.lang.UnsupportedOperationException: Aggregate function 
'last_non_null_value' does not support retraction, If you allow this function 
to ignore retraction messages, you can configure 
'fields.${field_name}.ignore-retract'='true'.
+```
 
 An explanation can be found in the official documentation:
 
+```
 Only sum supports retraction (UPDATE_BEFORE and DELETE), other aggregate 
functions do not support retraction.
+```
 
-This can be understood as: except for the SUM function, other Agg functions do 
not support Retraction. To avoid errors when receiving DELETE and UPDATEBEFORE 
messages, it is necessary to configure 
'fields.${field_name}.ignore-retract'='true' for the specified field to ignore 
retraction and solve this error.
+This can be understood as: except for the SUM function, other Agg functions do 
not support Retraction. To avoid errors when receiving DELETE and UPDATEBEFORE 
messages, it is necessary to configure 
`'fields.${field_name}.ignore-retract'='true'` for the specified field to 
ignore retraction and solve this error.
 
 ```sql
 WITH (
diff --git a/community/release/How-to-release.md 
b/community/release/How-to-release.md
index f2b99297..bcc6753a 100644
--- a/community/release/How-to-release.md
+++ b/community/release/How-to-release.md
@@ -186,9 +186,9 @@ $ mvn --encrypt-master-password <apache password>
 {EM+4/TYVDXYHRbkwjjAS3mE1RhRJXJUSG8aIO5RSxuHU26rKCjuS2vG+/wMjz9te}
 ```
 
-- Create the file ${user.home}/.m2/settings-security.xml and configure the 
password created in the previous step
+- Create the file `${user.home}/.m2/settings-security.xml` and configure the 
password created in the previous step
 
-```shell
+```xml
 <settingsSecurity>
   
<master>{EM+4/TYVDXYHRbkwjjAS3mE1RhRJXJUSG8aIO5RSxuHU26rKCjuS2vG+/wMjz9te}</master>
 </settingsSecurity>
@@ -242,7 +242,7 @@ $ mvn --encrypt-password <apache passphrase>
 
 ## 3. Prepare material package & release Apache Nexus
 
-#### 3.1 Based on the dev branch, create a release-${release_version}-rcx 
branch, such as release-2.1.0-rc1, And create a tag named v2.1.0-rc1 based on 
the release-2.1.0-rc1 branch, and set this tag as pre-release.
+#### 3.1 Based on the dev branch, create a `release-${release_version}-rcx` 
branch, such as release-2.1.0-rc1, And create a tag named v2.1.0-rc1 based on 
the release-2.1.0-rc1 branch, and set this tag as pre-release.
 
 
![图片](https://user-images.githubusercontent.com/19602424/236656362-1d346faa-6582-44eb-9722-8bb2de0eaa92.png)
 
@@ -409,7 +409,7 @@ apache-streampark_2.12-2.1.0-incubating-bin.tar.gz: OK
 svn co --depth empty 
https://dist.apache.org/repos/dist/dev/incubator/streampark 
dist/streampark_svn_dev
 ```
 
-Create a version number directory and name it in the form of 
${release_version}-${RC_version}. RC_version starts from 1, that is, the 
candidate version starts from RC1. During the release process, there is a 
problem that causes the vote to fail. If it needs to be corrected, it needs to 
iterate the RC version , the RC version number needs to be +1. For example: 
Vote for version 2.1.0-RC1. If the vote passes without any problems, the RC1 
version material will be released as the final versi [...]
+Create a version number directory and name it in the form of 
`${release_version}-${RC_version}`. RC_version starts from 1, that is, the 
candidate version starts from RC1. During the release process, there is a 
problem that causes the vote to fail. If it needs to be corrected, it needs to 
iterate the RC version , the RC version number needs to be +1. For example: 
Vote for version 2.1.0-RC1. If the vote passes without any problems, the RC1 
version material will be released as the final ver [...]
 
 ```shell
 mkdir -p dist/streampark_svn_dev/2.1.0-RC1
diff --git 
a/i18n/zh-CN/docusaurus-plugin-content-blog/3-streampark-usercase-bondex-paimon.md
 
b/i18n/zh-CN/docusaurus-plugin-content-blog/3-streampark-usercase-bondex-paimon.md
index 11b0ab85..ca6bab70 100644
--- 
a/i18n/zh-CN/docusaurus-plugin-content-blog/3-streampark-usercase-bondex-paimon.md
+++ 
b/i18n/zh-CN/docusaurus-plugin-content-blog/3-streampark-usercase-bondex-paimon.md
@@ -846,13 +846,18 @@ set 'table.exec.sink.upsert-materialize' = 'none'
 **3. Aggregate function 'last_non_null_value' does not support retraction**
 
 报错:
+
+```
 Caused by: java.lang.UnsupportedOperationException: Aggregate function 
'last_non_null_value' does not support retraction, If you allow this function 
to ignore retraction messages, you can configure 
'fields.${field_name}.ignore-retract'='true'.
+```
 
 可以在官方文档找到解释:
 
+```
 Only sum supports retraction (UPDATE_BEFORE and DELETE), others aggregate 
functions do not support retraction.
+```
 
-可以理解为:除了 SUM 函数,其他的 Agg 函数都不支持 Retraction,为了避免接收到 DELETE 和 UPDATEBEFORE 
消息报错,需要通过给指定字段配 'fields.${field_name}.ignore-retract'='true' 忽略,解决这个报错
+可以理解为:除了 SUM 函数,其他的 Agg 函数都不支持 Retraction,为了避免接收到 DELETE 和 UPDATEBEFORE 
消息报错,需要通过给指定字段配 `'fields.${field_name}.ignore-retract'='true'` 忽略,解决这个报错
 
 ```sql
 WITH (
diff --git 
a/i18n/zh-CN/docusaurus-plugin-content-docs-community/current/release/How-to-release.md
 
b/i18n/zh-CN/docusaurus-plugin-content-docs-community/current/release/How-to-release.md
index 55b142a5..52a0eb7c 100644
--- 
a/i18n/zh-CN/docusaurus-plugin-content-docs-community/current/release/How-to-release.md
+++ 
b/i18n/zh-CN/docusaurus-plugin-content-docs-community/current/release/How-to-release.md
@@ -186,9 +186,9 @@ $ mvn --encrypt-master-password <apache password>
 {EM+4/TYVDXYHRbkwjjAS3mE1RhRJXJUSG8aIO5RSxuHU26rKCjuS2vG+/wMjz9te}
 ```
 
-- 创建文件 ${user.home}/.m2/settings-security.xml 并配置上一步创建的密码
+- 创建文件 `${user.home}/.m2/settings-security.xml` 并配置上一步创建的密码
 
-```shell
+```xml
 <settingsSecurity>
   
<master>{EM+4/TYVDXYHRbkwjjAS3mE1RhRJXJUSG8aIO5RSxuHU26rKCjuS2vG+/wMjz9te}</master>
 </settingsSecurity>
@@ -242,7 +242,7 @@ $ mvn --encrypt-password <apache passphrase>
 
 ## 3. 准备物料 & 发布到Apache Nexus
 
-#### 3.1 
基于dev分支,创建一个名为release-${release_version}-rcx的分支,例如release-2.1.0-rc1。并基于release-2.1.0-rc1分支创建一个名为v2.1.0-rc1的标签,并将此标签设置为预发布。
+#### 3.1 基于 dev 分支,创建一个名为 `release-${release_version}-rcx` 的分支,例如 
release-2.1.0-rc1。并基于 release-2.1.0-rc1 分支创建一个名为 v2.1.0-rc1 的标签,并将此标签设置为预发布。
 
 
![图片](https://user-images.githubusercontent.com/19602424/236656362-1d346faa-6582-44eb-9722-8bb2de0eaa92.png)
 
@@ -409,7 +409,7 @@ apache-streampark_2.12-2.1.0-incubating-bin.tar.gz: OK
 svn co --depth empty 
https://dist.apache.org/repos/dist/dev/incubator/streampark 
dist/streampark_svn_dev
 ```
 
-创建一个版本号目录,并以${release_version}-${RC_version}的形式命名。RC_version从1开始,即候选版本从RC1开始。在发布过程中,如果出现导致投票失败的问题,需要进行修正,那么RC版本需要迭代,RC版本号需要+1。例如:为版本2.1.0-RC1投票。如果投票顺利通过,那么RC1版本的资料将作为最终版本的资料发布。如果出现问题(当streampark/incubator社区进行投票时,投票者会严格检查各种发布要求和合规问题)并需要纠正,那么修正后重新启动投票,下一次的候选版本为2.1.0-RC2。
+创建一个版本号目录,并以 `${release_version}-${RC_version}` 
的形式命名。RC_version从1开始,即候选版本从RC1开始。在发布过程中,如果出现导致投票失败的问题,需要进行修正,那么RC版本需要迭代,RC版本号需要+1。例如:为版本2.1.0-RC1投票。如果投票顺利通过,那么RC1版本的资料将作为最终版本的资料发布。如果出现问题(当streampark/incubator社区进行投票时,投票者会严格检查各种发布要求和合规问题)并需要纠正,那么修正后重新启动投票,下一次的候选版本为2.1.0-RC2。
 
 ```shell
 mkdir -p dist/streampark_svn_dev/2.1.0-RC1
diff --git a/package.json b/package.json
index 332ea8b7..a6d93dc4 100644
--- a/package.json
+++ b/package.json
@@ -23,29 +23,29 @@
     "@docusaurus/theme-mermaid": "3.3.2",
     "@docusaurus/utils-common": "3.3.2",
     "@easyops-cn/docusaurus-search-local": "^0.36.0",
-    "@mdx-js/react": "^1.6.22",
-    "@svgr/webpack": "^6.2.1",
+    "@mdx-js/react": "^3.0.1",
+    "@svgr/webpack": "^6.5.1",
     "aos": "^2.3.4",
     "clsx": "^1.2.1",
     "file-loader": "^6.2.0",
-    "framer-motion": "^10.13.1",
+    "framer-motion": "^10.18.0",
     "[email protected]": "link:docusaurus/[email protected]",
-    "prism-react-renderer": "^1.3.1",
-    "prismjs": "^1.28.0",
-    "react": "^18.2.0",
+    "prism-react-renderer": "^1.3.5",
+    "prismjs": "^1.29.0",
+    "react": "^18.3.1",
     "react-copy-to-clipboard": "^5.1.0",
-    "react-dom": "^18.2.0",
+    "react-dom": "^18.3.1",
     "react-tsparticles": "^2.12.2",
-    "sass-loader": "^13.0.2",
+    "sass-loader": "^13.3.3",
     "url-loader": "^4.1.1"
   },
   "devDependencies": {
     "@docusaurus/module-type-aliases": "2.4.3",
-    "@tsconfig/docusaurus": "^1.0.4",
+    "@tsconfig/docusaurus": "^1.0.7",
     "docusaurus-plugin-less": "^2.0.2",
-    "less": "^4.1.2",
+    "less": "^4.2.0",
     "less-loader": "^10.2.0",
-    "typescript": "^4.5.5"
+    "typescript": "^4.9.5"
   },
   "browserslist": {
     "production": [
diff --git a/pnpm-lock.yaml b/pnpm-lock.yaml
index 0ef72522..e33103e0 100644
--- a/pnpm-lock.yaml
+++ b/pnpm-lock.yaml
@@ -27,10 +27,10 @@ dependencies:
     specifier: ^0.36.0
     version: 
0.36.0(@docusaurus/[email protected])([email protected])([email protected])([email protected])
   '@mdx-js/react':
-    specifier: ^1.6.22
-    version: 1.6.22([email protected])
+    specifier: ^3.0.1
+    version: 3.0.1(@types/[email protected])([email protected])
   '@svgr/webpack':
-    specifier: ^6.2.1
+    specifier: ^6.5.1
     version: 6.5.1
   aos:
     specifier: ^2.3.4
@@ -42,31 +42,31 @@ dependencies:
     specifier: ^6.2.0
     version: 6.2.0([email protected])
   framer-motion:
-    specifier: ^10.13.1
+    specifier: ^10.18.0
     version: 10.18.0([email protected])([email protected])
   [email protected]:
     specifier: link:docusaurus/[email protected]
     version: link:docusaurus/[email protected]
   prism-react-renderer:
-    specifier: ^1.3.1
+    specifier: ^1.3.5
     version: 1.3.5([email protected])
   prismjs:
-    specifier: ^1.28.0
+    specifier: ^1.29.0
     version: 1.29.0
   react:
-    specifier: ^18.2.0
+    specifier: ^18.3.1
     version: 18.3.1
   react-copy-to-clipboard:
     specifier: ^5.1.0
     version: 5.1.0([email protected])
   react-dom:
-    specifier: ^18.2.0
+    specifier: ^18.3.1
     version: 18.3.1([email protected])
   react-tsparticles:
     specifier: ^2.12.2
     version: 2.12.2([email protected])
   sass-loader:
-    specifier: ^13.0.2
+    specifier: ^13.3.3
     version: 13.3.3([email protected])
   url-loader:
     specifier: ^4.1.1
@@ -77,19 +77,19 @@ devDependencies:
     specifier: 2.4.3
     version: 2.4.3([email protected])([email protected])
   '@tsconfig/docusaurus':
-    specifier: ^1.0.4
+    specifier: ^1.0.7
     version: 1.0.7
   docusaurus-plugin-less:
     specifier: ^2.0.2
     version: 2.0.2(@docusaurus/[email protected])([email protected])([email protected])
   less:
-    specifier: ^4.1.2
+    specifier: ^4.2.0
     version: 4.2.0
   less-loader:
     specifier: ^10.2.0
     version: 10.2.0([email protected])([email protected])
   typescript:
-    specifier: ^4.5.5
+    specifier: ^4.9.5
     version: 4.9.5
 
 packages:
@@ -2908,14 +2908,6 @@ packages:
     transitivePeerDependencies:
       - supports-color
 
-  /@mdx-js/[email protected]([email protected]):
-    resolution: {integrity: 
sha512-TDoPum4SHdfPiGSAaRBw7ECyI8VaHpK8GJugbJIJuqyh6kzw9ZLJZW3HGL3NNrJGxcAixUvqROm+YuQOo5eXtg==}
-    peerDependencies:
-      react: ^16.13.1 || ^17.0.0
-    dependencies:
-      react: 18.3.1
-    dev: false
-
   /@mdx-js/[email protected](@types/[email protected])([email protected]):
     resolution: {integrity: 
sha512-9ZrPIU4MGf6et1m1ov3zKf+q9+deetI51zprKB1D/z3NOb+rUxxtEl3mCjW5wTGh6VhRdwPueh1oRzi6ezkA8A==}
     peerDependencies:
diff --git a/src/theme/DocCard/index.js b/src/theme/DocCard/index.js
index 7513f565..f904d571 100644
--- a/src/theme/DocCard/index.js
+++ b/src/theme/DocCard/index.js
@@ -2,10 +2,9 @@ import React from 'react';
 import clsx from 'clsx';
 import Link from '@docusaurus/Link';
 import {
-  findFirstCategoryLink,
+  findFirstSidebarItemLink,
   useDocById,
 } from '@docusaurus/theme-common/internal';
-import isInternalUrl from '@docusaurus/isInternalUrl';
 import {translate} from '@docusaurus/Translate';
 import styles from './styles.module.css';
 function CardContainer({href, children}) {
@@ -34,7 +33,7 @@ function CardLayout({href, icon, title, description}) {
   );
 }
 function CardCategory({item}) {
-  const href = findFirstCategoryLink(item);
+  const href = findFirstSidebarItemLink(item);
   // Unexpected: categories that don't have a link have been filtered upfront
   if (!href) {
     return null;
diff --git a/src/theme/DocSidebarItem/Category/index.js 
b/src/theme/DocSidebarItem/Category/index.js
index 720e7789..98790a82 100644
--- a/src/theme/DocSidebarItem/Category/index.js
+++ b/src/theme/DocSidebarItem/Category/index.js
@@ -9,7 +9,7 @@ import {
 } from '@docusaurus/theme-common';
 import {
   isActiveSidebarItem,
-  findFirstCategoryLink,
+  findFirstSidebarItemLink,
   useDocSidebarItemsExpandedState,
   isSamePath,
 } from '@docusaurus/theme-common/internal';
@@ -44,11 +44,11 @@ function useCategoryHrefWithSSRFallback(item) {
       return item.href;
     }
     // In these cases, it's not necessary to render a fallback
     // We skip the "findFirstCategoryLink" computation
     if (isBrowser || !item.collapsible) {
       return undefined;
     }
-    return findFirstCategoryLink(item);
+    return findFirstSidebarItemLink(item);
   }, [item, isBrowser]);
 }
 function CollapseButton({categoryLabel, onClick}) {
@@ -44,11 +44,11 @@ function useCategoryHrefWithSSRFallback(item) {
     }
     // In these cases, it's not necessary to render a fallback
-    // We skip the "findFirstCategoryLink" computation
+    // We skip the "findFirstSidebarItemLink" computation
     if (isBrowser || !item.collapsible) {
       return undefined;

Reply via email to